import './style.css'
import { Map, TileLayer, GroupGLLayer } from 'maptalks-gl';
import * as THREE from 'three';
import { ThreeLayer, BaseObject } from 'maptalks.three';
import { HeatLayer } from 'maptalks.heatlayer';

const map = new Map("map", {
  center: [120, 31],
  zoom: 9,
});


const sceneConfig = {
  postProcess: {
    enable: true,
    antialias: {
      enable: true,
    },
  },
};


const group = new GroupGLLayer('group', [], {
  sceneConfig
});
group.addTo(map);


const tileLayer = new TileLayer("tilelayer", {
  urlTemplate: "https://webrd01.is.autonavi.com/appmaptile?lang=zh_cn&size=1&scale=1&style=8&x={x}&y={y}&z={z}",
  subdomains: ["a", "b", "c", "d"],
}).addTo(group);

const threeLayer = new ThreeLayer('t', {
  identifyCountOnEvent: 1
});

threeLayer.prepareToDraw = function (gl, scene, camera) {
  var light = new THREE.DirectionalLight(0xffffff);
  light.position.set(0, -10, 10).normalize();
  scene.add(light);
  scene.add(new THREE.AmbientLight('#fff', 0.3));
  testThreeLayer();
};
threeLayer.addTo(group);

const heatLayer = new HeatLayer('heatlayer', {
  max: 10,
  size: 10,
  progressiveRender: true,
  progressiveRenderCount: 3000,
}).addTo(map);

function testThreeLayer() {
  const bar = threeLayer.toBar(map.getCenter(), { radius: 10000, height: 10000 }, new THREE.MeshLambertMaterial({ color: 'blue' }));
  threeLayer.addMesh(bar);
}

function randomHeatData() {
  const { x, y } = map.getCenter();
  const data = [];
  while (data.length < 5000) {
    const cx = Math.random() + x - 0.5;
    const cy = Math.random() + y - 0.5;
    data.push({
      coordinates: [cx, cy],
      count: 1
    })
  }
  return data;
}

heatLayer.setData(randomHeatData())




